package com.microservices.zone.journals.service;

import com.microservices.zone.journals.domain.ZoneJournals;
import com.microservices.zone.journals.domain.vo.ZoneJournalsInputVo;
import com.microservices.zone.journals.domain.vo.ZoneJournalsParentDataVo;
import com.microservices.zone.journals.domain.vo.ZoneJournalsSearchVo;
import com.microservices.zone.journals.domain.vo.ZoneJournalsUpdateVo;

import java.util.List;

/**
 * 通用评论Service接口
 *
 * @author otto
 * @date 2025-04-30
 */
public interface IZoneJournalsService {

    /**
     * 查询评论
     *
     * @param id 评论主键
     * @return 评论
     */
    ZoneJournals selectZoneJournalsById(Long id);

    /**
     * 查询评论列表（二级结构）
     *
     * @param searchVo 查询条件
     * @return 评论列表（父评论包含子评论）
     */
    List<ZoneJournalsParentDataVo> selectJournalsList(ZoneJournalsSearchVo searchVo);

    /**
     * 新增评论
     *
     * @param inputVo 评论输入信息
     * @return 评论ID
     */
    Long insertJournals(ZoneJournalsInputVo inputVo);

    /**
     * 修改评论
     *
     * @param updateVo 评论更新信息
     * @return 结果
     */
    int updateJournals(ZoneJournalsUpdateVo updateVo);

    /**
     * 删除评论（级联删除子评论）
     *
     * @param id 评论主键
     * @return 结果
     */
    int deleteJournalsById(Long id);

    /**
     * 批量删除评论
     *
     * @param ids 需要删除的评论主键集合
     * @return 结果
     */
    int deleteJournalsByIds(Long[] ids);

    /**
     * 根据类型和评论对象Id删除所有评论
     *
     * @param type      类型
     * @param journalId 评论对象Id
     */
    void deleteJournalsByTypeAndJournalId(String type, Long journalId);

    /**
     * 批量更新关联ID
     *
     * @param type        类型
     * @param oldJournalId 旧评论对象Id
     * @param journalId   新评论对象Id
     */
    void updateJournalsIdByTypeAndOldId(String type, Long oldJournalId, Long journalId);
}
